# Makestack

Python CLI that builds custom environments.

## Install

```bash
pip install makestack
```

### Installing from source

```bash
git clone https://github.com/makepath/makestack
cd makestack
pip install .
```

## Usage

After installing Makestack, you can run the CLI by typing `makestack` in your terminal.
